# mkdocs-wordart
A MkDocs plugin that makes wordart available again.

Thanks a lot to [arizzitano](https://github.com/arizzitano) with the awesome [css3wordart project](https://github.com/arizzitano/css3wordart), all the css comes from there.
